@@ -73,11 +73,12 @@ _service_endpoints_template = {
     'transfer': '{proto}://{host}:4618',
     'acm': '{proto}://{host}:4619',
     'codecommit': '{proto}://{host}:4620',
-    'kinesisanalytics': '{proto}://{host}:4621'
+    'kinesisanalytics': '{proto}://{host}:4621',
+    'amplify': '{proto}://{host}:4622'
 }
 
 # TODO remove service port mapping above entirely
-if os.environ.get('USE_LEGACY_PORTS') in ['0', 'false']:
+if os.environ.get('USE_LEGACY_PORTS') not in ['1', 'true']:
     for key, value in _service_endpoints_template.items():
         if key != 'dashboard':
             _service_endpoints_template[key] = '%s:%s' % (value.rpartition(':')[0], EDGE_PORT)
